@@ -168,6 +168,25 @@ class Parser:
 
             if len(table_name.split('.')) == 2:
                 queried_cols.append({table_name: set(meta_cols[meta_cols['db_table'] == table_name]['all_columns'])})
+            
+        return queried_cols
+
+
+    def _get_queried_columns_spark(self, table_names, meta_cols):
+        """
+        Get all columns by looking up referenced Spark table names in the metacolumn file.
+        Args:
+            param1 (dict): A dictionary of mapping of table/subquery referenced in query and their aliases.
+            param2 (dict): A dictionary of metadata columns from Glue.
+        Returns:
+            list: A list of {key, value} pairs, each pair reflecting the table name and all columns under the table, from Glue metastore.
+        """
+        queried_cols = []
+
+        for _,table_name in table_names.items():
+
+            if len(table_name.split('.')) == 2:
+                queried_cols.append({table_name: set(meta_cols.filter(meta_cols['db_table']==table_name).collect()[0][1])})
 
         return queried_cols
             
@@ -253,6 +272,35 @@ class Parser:
         return all_columns_scanned
 
 
+    def _get_all_scanned_cols_spark(self, cte_queries, meta_cols):
+        """
+        Get all scanned original columns.
+        Args:
+            param1 (dict): A dictionary of CTE's name:query pair.
+            param2 (dict): A dictionary of metadata columns from Glue.
+        Returns:
+            list: A list of all scanned columns with db and table names.
+        """
+        all_columns_scanned = []
+
+        for _,cte_query in cte_queries.items():
+
+            table_alias_mapping = self.get_table_names(cte_query.split('\n'))
+            variables = self._get_all_variables(cte_query)
+            queried_columns = self._get_queried_columns_spark(table_alias_mapping, meta_cols)
+            if variables == []:
+                original_columns_list = []
+                for table in queried_columns:
+                    for k,v in table.items():
+                        for t in v:
+                            original_columns_list.append("{}.{}".format(k,t))
+            else:
+                original_columns_list = self._map_db_columns(variables, queried_columns, table_alias_mapping)
+            all_columns_scanned.extend(list(set(original_columns_list)))
+
+        return all_columns_scanned
+
+
     def match_queried_fields(self, query, db_fields, **kwargs):
         """
         Match the query column with those registered on metastore.
@@ -290,3 +338,42 @@ class Parser:
                 pass
 
         return column_payload
+
+
+    def match_queried_fields_spark(self, query, db_fields, **kwargs):
+        """
+        Match the query column with those registered on metastore.
+        Args:
+            query (string): the raw query.
+            db_fields (spark dataframe): dataframe containing column names.
+            **kargs: other metadata around query execution that needs to be populated to payload.
+
+        Return:
+            column_payload (json): the queried columns, table and db.
+        """
+        logging.info("Reading and formatting query...")
+        
+        formatted_query = self.format_query(query)
+        cte_queries = self.parse_cte(formatted_query)
+
+        logging.info("Mapping and retrieving columns from query...")
+        all_columns_scanned = self._get_all_scanned_cols_spark(cte_queries, db_fields)
+        logging.info("All columns scanned in the query: {}.".format(all_columns_scanned))
+
+        column_payload = []
+        for column in all_columns_scanned:
+            try:
+                col_split = column.split('.')
+                db, table, col = col_split[0], col_split[1], col_split[2]
+                row_payload = dict()
+                row_payload["database_name"] = db
+                row_payload["table_name"] = table 
+                row_payload["column_name"] = col
+                for arg, value in kwargs.items():
+                    row_payload[arg] = value    
+
+                column_payload.append(row_payload)  
+            except:
+                pass
+
+        return column_payload
